==> fwbuilder_1.0.0.orig.tar.gz: fwbuilder-1.0.0.orig/src/gui/ASDruidP12Dialog.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 Vadim Kurland

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: ASDruidP12Dialog.cc,v 1.10 2001/12/18 22:48:29 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#include "ASDruidP12Dialog.hh"
#include "helpers.hh"
#include "fwbuilder/FWObjectDatabase.hh"

using namespace libfwbuilder;


ASDruidP12Dialog::ASDruidP12Dialog()
{
    FWObject *frag;
    frag=_findObjectByName(FWObjectDatabase::db->std.ServicesId,"ip_fragments");
    if (frag==NULL) short_fragments->set_sensitive(false);

    setButtonLblAlignment(anti_spoof_in  , 0.0, 0.5);
    setButtonLblAlignment(anti_spoof_out , 0.0, 0.5);
    setButtonLblAlignment(short_fragments, 0.0, 0.5);
    setButtonLblAlignment(allow_all_on_loopback   , 0.0, 0.5);
    setButtonLblAlignment(masquerading   , 0.0, 0.5);
    setButtonLblAlignment(catch_all      , 0.0, 0.5);

    p12_txt_1->set_line_wrap(true);
    p12_txt_2->set_line_wrap(true);
}

==> fwbuilder_1.1.2.orig.tar.gz: fwbuilder-1.1.2/src/gui/ASDruidP12Dialog.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: ASDruidP12Dialog.cc,v 1.14 2002/11/28 08:12:59 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#include "fwbuilder/libfwbuilder-config.h"
#include "ASDruidP12Dialog.hh"
#include "helpers.hh"
#include "FWObjectDatabaseGUI.hh"

using namespace libfwbuilder;


ASDruidP12Dialog::ASDruidP12Dialog()
{
    FWObject *frag;
    frag=_findObjectByName(FWObjectDatabaseGUI::getServicesId(),"ip_fragments");
    if (frag==NULL) short_fragments->set_sensitive(false);

    setButtonLblAlignment(anti_spoof_in  , 0.0, 0.5);
    setButtonLblAlignment(anti_spoof_out , 0.0, 0.5);
    setButtonLblAlignment(short_fragments, 0.0, 0.5);
    setButtonLblAlignment(allow_all_on_loopback   , 0.0, 0.5);
    setButtonLblAlignment(masquerading   , 0.0, 0.5);
    setButtonLblAlignment(catch_all      , 0.0, 0.5);

    p12_txt_1->set_line_wrap(true);
//    p12_txt_2->set_line_wrap(true);
}
